starcluster.plugins.tmux.TmuxControlCenter

Package starcluster :: Package plugins :: Module tmux :: Class TmuxControlCenter |
[hide private]
[frames] | no frames]

# Class TmuxControlCenter

source code

Starts a TMUX session on StarCluster configured with split panes for all nodes. This allows you to interactively run commands on all nodes and see all the output at once.

Instance Methods | [hide private]
__init__(self, envname=`'``starcluster``'`) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
_supports_layout(self, node, envname, layout, window=`'````'`) | source code
_select_layout(self, node, envname, layout=`'``main-vertical``'`, window=`'````'`) | source code
_resize_pane(self, node, envname, pane, units, up=False) | source code
_split_window(self, node, envname, window=`'````'`, vertical=False) | source code
_rename_window(self, node, envname, window, name) | source code
_has_session(self, node, envname) | source code
_send_keys(self, node, envname, cmd, window=`'````'`) | source code
_new_session(self, node, envname) | source code
_kill_session(self, node, envname) | source code
_new_window(self, node, envname, title) | source code
_select_window(self, node, envname, window=`'````'`) | source code
_select_pane(self, node, envname, window, pane) | source code
create_session(self, node, envname, num_windows=5) | source code
setup_tmuxcc(self, client=None, nodes=None, user=`'``root``'`, layout=`'``tiled``'`) | source code
add_to_utmp_group(self, client, user) Adds user (if exists) to 'utmp' group (if exists) | source code
run(self, nodes, master, user, user_shell, volumes) Start cluster configuration | source code
on_add_node(self, node, nodes, master, user, user_shell, volumes) This methods gets executed after a node has been added to the cluster | source code
on_remove_node(self, node, nodes, master, user, user_shell, volumes) This method gets executed before a node is about to be removed from the cluster | source code
Inherited from `clustersetup.DefaultClusterSetup` (private): `_add_sge_administrative_host`, `_add_sge_submit_host`, `_add_to_sge`, `_add_user_to_node`, `_add_user_to_nodes`, `_create_sge_pe`, `_create_user`, `_get_nfs_export_paths`, `_mount_nfs_shares`, `_remove_from_etc_hosts`, `_remove_from_known_hosts`, `_remove_from_sge`, `_remove_nfs_exports`, `_setup_cluster_user`, `_setup_ebs_volumes`, `_setup_etc_hosts`, `_setup_hostnames`, `_setup_nfs`, `_setup_passwordless_ssh`, `_setup_scratch`, `_setup_scratch_on_node`, `_setup_sge` Inherited from `clustersetup.ClusterSetup`: `on_restart`, `on_shutdown` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| _layouts = ``[``'``even-horizontal``'``,` `'``even-vertical``'``,` `'``main-horizont``...``

Properties | [hide private]
Inherited from `clustersetup.DefaultClusterSetup`: `nodes`, `pool`, `running_nodes` Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, envname=`'``starcluster``'`) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### run(self, nodes, master, user, user_shell, volumes) | source code
Start cluster configuration Overrides: clustersetup.ClusterSetup.run (inherited documentation)

### on_add_node(self, node, nodes, master, user, user_shell, volumes) | source code
This methods gets executed after a node has been added to the cluster Overrides: clustersetup.ClusterSetup.on_add_node (inherited documentation)

### on_remove_node(self, node, nodes, master, user, user_shell, volumes) | source code
This method gets executed before a node is about to be removed from the cluster Overrides: clustersetup.ClusterSetup.on_remove_node (inherited documentation)

Class Variable Details | [hide private]

  ### _layouts Value:
      ['even-horizontal',
       'even-vertical',
       'main-horizontal',
       'main-vertical',
       'tiled']